# The version of Subversion that we are compatible with
%global svn_version 1.8.1

Name:           svnkit
Version:        1.8.12
Release:        %mkrel 9
Summary:        Pure Java library to manage Subversion working copies and repositories

Group:          Development/Java
# License located at https://svnkit.com/license.html
License:        TMate and ASL 2.0
URL:            https://www.svnkit.com/
Source0:        https://www.svnkit.com/org.tmatesoft.svn_%{version}.src.zip

# POMs
Source1:        https://repo1.maven.org/maven2/org/tmatesoft/svnkit/svnkit/%{version}/svnkit-%{version}.pom
Source2:        https://repo1.maven.org/maven2/org/tmatesoft/svnkit/svnkit-cli/%{version}/svnkit-cli-%{version}.pom
Source3:        https://repo1.maven.org/maven2/org/tmatesoft/svnkit/svnkit-javahl16/%{version}/svnkit-javahl16-%{version}.pom

# Custom aggregator pom to avoid reliance on gradle
Source4:        svnkit-parent.pom

# SVNKit provides a pure-Java implementation of the Subversion JavaHL API, but it only provides an older
# Subversion JavaHL API, so we need an old version of the JavaHL source to build against. This is that:
#  $ svn export https://svn.apache.org/repos/asf/subversion/tags/1.8.1/subversion/bindings/javahl/src/ javahl-1.8.1
Source5:        javahl-%{svn_version}.tar.gz

# License for the above JavaHL API:
Source6:        https://www.apache.org/licenses/LICENSE-2.0.txt

# svnkit's trilead-ssh2 does not throw InterruptedException from Session.waitForCondition()
# Fedora's trilead-ssh2 does ...
Patch1:         svnkit-1.8.5-SshSession-unreported-exception.patch

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  mvn(com.jcraft:jsch.agentproxy.connector-factory)
BuildRequires:  mvn(com.jcraft:jsch.agentproxy.svnkit-trilead-ssh2)
BuildRequires:  mvn(com.trilead:trilead-ssh2)
BuildRequires:  mvn(de.regnis.q.sequence:sequence-library)
BuildRequires:  mvn(net.java.dev.jna:jna)
BuildRequires:  mvn(net.java.dev.jna:jna-platform)
BuildRequires:  mvn(org.tmatesoft.sqljet:sqljet)

%description
SVNKit is a pure java Subversion client library. You would like to use SVNKit
when you need to access or modify Subversion repository from your Java
application, as a standalone program and plugin or web application. Being a
pure java program, SVNKit doesn't need any additional configuration or native
binaries to work on any OS that runs java.

%package cli
Summary: SVNKit based Subversion command line client
# Explicit requires for javapackages-tools since scripts
# use /usr/share/java-utils/java-functions
Requires:       javapackages-tools

%description cli
%{summary}.

%package javahl
Summary: SVNKit based Subversion JavaHL API implementation

%description javahl
%{summary}.

%package javadoc
Summary: Javadoc for SVNKit

%description javadoc
API documentation for SVNKit.

%prep
%setup -q -n %{name}-%{version}

%patch -P 1 -p1

# Delete all pre-built binaries, except for "template.jar" which is important
# for the function of svnkit and contains no actual bytecode:
find -name *.class -delete
find -name *.jar -a ! -name template.jar -delete

cp -pr %{SOURCE1} svnkit/pom.xml
cp -pr %{SOURCE2} svnkit-cli/pom.xml
cp -pr %{SOURCE3} svnkit-javahl16/pom.xml
cp -pr %{SOURCE4} pom.xml

# Build against the bundled version of the JavaHL API source
cp -pr %{SOURCE6} ASL-2.0.txt
(cd svnkit-javahl16/src/main/java/ &&  tar xf %{SOURCE5} --strip-components=1 --skip-old-files)
%pom_remove_dep ":svn-javahl-api" svnkit-javahl16
%pom_remove_dep ":svn-javahl-tests" svnkit-javahl16

# Generate properties file
rev="t$(date -u +%Y%m%d%H%M)"
cat > svnkit/src/main/resources/svnkit.build.properties <<EOF
svnkit.version=%{version}
build.number=$rev

svnkit.version.string=SVN/%{svn_version} SVNKit/%{version} (http://svnkit.com/) $rev
svnkit.version.major=$(echo "%{version}" | cut -f1 -d.)
svnkit.version.minor=$(echo "%{version}" | cut -f2 -d.)
svnkit.version.micro=$(echo "%{version}" | cut -f3 -d.)
svnkit.version.revision=$rev

svnkit.svn.version=%{svn_version}
EOF

# Don't install our custom aggregator pom
%mvn_package ":parent" __noinstall

%build
# Upstream builds with ignore test failures set to true, so I guess we shouldn't expect them to work...
# Let's skip tests for now.
%mvn_build -s -f -- -Dproject.buildVersion.baseVersion=%{version} \
  -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8 -Dsource=1.8 -DdetectJavaApiLink=false

%install
%mvn_install

# Generate scripts for command line tools
for class in SVN SVNAdmin SVNDumpFilter SVNLook SVNSync SVNVersion ; do
  mainclass=org.tmatesoft.svn.cli.$class
  script=j$(echo $class | tr '[:upper:]' '[:lower:]')
  %jpackage_script "$mainclass" "-Dsun.io.useCanonCaches=false" "" "svnkit:sequence-library:sqljet:antlr32/antlr-runtime-3.2:trilead-ssh2" "$script" true
done

%files -f .mfiles-svnkit
%license LICENSE.txt ASL-2.0.txt
%doc README.txt CHANGES.txt

%files cli -f .mfiles-svnkit-cli
%{_bindir}/*

%files javahl -f .mfiles-svnkit-javahl16

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt ASL-2.0.txt



%changelog
* Mon May 27 2024 ns80 <ns80> 1.8.12-9.mga10
+ Revision: 2068106
- rebuild for java 21

* Sat Mar 26 2022 umeabot <umeabot> 1.8.12-8.mga9
+ Revision: 1827675
- Mageia 9 Mass Rebuild

* Sat Jan 09 2021 daviddavid <daviddavid> 1.8.12-7.mga8
+ Revision: 1670026
- Use https for maven central URLs
- Fix javadoc generation when building against JDK 11
- Install ASL 2.0 license

* Wed Feb 12 2020 umeabot <umeabot> 1.8.12-6.mga8
+ Revision: 1508158
- Mageia 8 Mass Rebuild

* Fri Sep 21 2018 umeabot <umeabot> 1.8.12-5.mga7
+ Revision: 1291728
- Mageia 7 Mass Rebuild

* Thu May 03 2018 daviddavid <daviddavid> 1.8.12-4.mga7
+ Revision: 1225501
- sync with fc29 to fix FTBFS

* Mon Oct 02 2017 daviddavid <daviddavid> 1.8.12-3.mga7
+ Revision: 1162665
- add missing BR on javapackages-local to fix build
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 1.8.12-2.mga6
+ Revision: 978579
- First rebuild of the java stack
- sync package svnkit with fedora


* Mon Dec 13 2010 Alexander Kurtakov <akurtako@redhat.com> 1.3.4-2
- Fix pom name.
- Adapt to current guidelines.

* Thu Oct 21 2010 Alexander Kurtakov <akurtako@redhat.com> 1.3.4-1
- Update to new upstream 1.3.4.

* Wed Jul 21 2010 Alexander Kurtakov <akurtako@redhat.com> 1.3.3-5
- Add maven depmap and pom.
- Separate javahl in a subpackage.

* Fri Jul 16 2010 Alexander Kurtakov <akurtako@redhat.com> 1.3.3-4
- Move eclipse-platform dependency to the eclipse subpackage.

* Tue Jul 13 2010 Alexander Kurtakov <akurtako@redhat.com> 1.3.3-3
- Fix antlr3 jar rename.

* Tue Jul 13 2010 Alexander Kurtakov <akurtako@redhat.com> 1.3.3-2
- BR antlr3-java.

* Tue Jul 13 2010 Alexander Kurtakov <akurtako@redhat.com> 1.3.3-1
- Update to 1.3.3.
- Patch1 is not applied it looks like fixed upstream in different way.

* Fri Mar 05 2010 Lubomir Rintel <lkundrak@v3.sk> 1.3.2-2
- Cherry-pick r6418 from upstream

* Thu Dec 3 2009 Alexander Kurtakov <akurtako@redhat.com> 1.3.2-1
- Update to 1.3.2.

* Fri Jul 24 2009 Alexander Kurtakov <akurtako@redhat.com> 1.3.0-1
- Update to 1.3.0.

* Mon Apr  6 2009 Robert Marcano <robert@marcanoonline.com> - 1.2.3-2
- Rebuild

* Mon Mar 23 2009 Robert Marcano <robert@marcanoonline.com> - 1.2.3-1
- Update to upstream 1.2.3

* Tue Feb 17 2009 Robert Marcano <robert@marcanoonline.com> - 1.2.2-1
- Update to upstream 1.2.2
- New eclipse-svnkit subpackage with eclipse plugin
- GCJ AOT removed

* Sun Sep  7 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.1.4-4
- fix license tag

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.1.4-3
- Autorebuild for GCC 4.3

* Thu Sep 20 2007 Robert Marcano <robert@marcanoonline.com> - 1.1.4-2
- Fix Obsoletes to include javasvn = 1.1.0

* Mon Sep 10 2007 Robert Marcano <robert@marcanoonline.com> - 1.1.4-1
- Update to upstream 1.1.4
- Build for all supported arquitectures 

* Wed Aug 29 2007 Fedora Release Engineering <rel-eng at fedoraproject dot org> - 1.1.2-4
- Rebuild for selinux ppc32 issue.

* Mon Jun 18 2007 Robert Marcano <robert@marcanoonline.com> 1.1.2-2
- Package review fixes

* Sun Apr 15 2007 Robert Marcano <robert@marcanoonline.com> 1.1.2-1
- Update to upstream 1.1.2
- Add obsoletes of javasvn

* Tue Feb 06 2007 Robert Marcano <robert@marcanoonline.com> 1.1.1-1
- Rename to svnkit
- Update to SVNKit 1.1.1

* Mon Aug 28 2006 Robert Marcano <robert@marcanoonline.com> 1.1.0-0.3.beta4
- Rebuild

* Thu Aug 03 2006 Robert Marcano <robert@marcanoonline.com> 1.1.0-0.2.beta4
- Fix bad relase tag

* Mon Jul 31 2006 Robert Marcano <robert@marcanoonline.com> 1.1.0-0.beta4
- Update to upstream version 1.1.0.beta4, required by subclipse 1.1.4

* Fri Jul 28 2006 Robert Marcano <robert@marcanoonline.com> 1.0.6-2
- Rebuilt to pick up the changes in GCJ (bug #200490)

* Mon Jun 26 2006 Robert Marcano <robert@marcanoonline.com> 1.0.6-1
- Update to upstream version 1.0.6

* Sun Jun 25 2006 Robert Marcano <robert@marcanoonline.com> 1.0.4-4
- created javadoc subpackage
- dependency changed from ganymed to ganymed-ssh2

* Sun Jun 11 2006 Robert Marcano <robert@marcanoonline.com> 1.0.4-3
- rpmlint fixes and debuginfo generation workaround
- doc files added

* Sun May 28 2006 Robert Marcano <robert@marcanoonline.com> 1.0.4-2
- review updates

* Sun May 07 2006 Robert Marcano <robert@marcanoonline.com> 1.0.4-1
- initial version
